package net.windwards.options;

import net.windwards.options.valueparsers.NullValueParser;
import net.windwards.options.valueparsers.ValueParser;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Option denotes a field that should be interpreted as a commandline 
 * option. The name of the denoted field is also the name of the commandline 
 * option. E.g.: \@Option public String givenName, becomes --givenName.
 * 
 * @author quest
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.FIELD)
public @interface Option {
	/**
	 * a short version of the option. E.g.: @Option(shortName='p') gives -p.
	 */
	public String shortName() default "";

	/**
	 * document the option's effect. Used to build usage message.
	 */
	public String documentation() default "";

    /**
     * use a custom ValueParser to interpret value for this option. Supply
     * a class reference that implements
     * {@link net.windwards.options.valueparsers.ValueParser}.
     */
    public Class<? extends ValueParser> valueParser() default NullValueParser.class;
}
